
;# altoids.pl
;# D Plonka, Sep  5 1997

;# altoids is a hash of hashes that's main purpose is to lookup oids give
;# a short name.  It's also used to supply hints about translations for
;# table keys and values.
;# The internal hashes contains these members:
;#
;#   humanoid (scalar) - the human-readable dotted-alpha "oid"
;#   oid (scalar) - the oid
;#   lhs (array) - an array of type specifiers for the "Left-Hand-Side" (oid)
;#                 This is used to make key values (which are encoded into the
;#                 returned oid) for "conceptual rows" human-readable.
;#                 Possible type specifiers are: 'nstring', 'string', 'atmaddr'.
;#                 This is an array of scalars because sometimes the keys
;#                 have multiple segments.
;#   rhs (scalar) - a type specifier for the "Right-Hand-Side" (ie. the value)
;#   rhstrans (hash) - a translation table for the "Right-Hand-Side"
;#                     This is often used to translate integer values into
;#                     meaningful strings.

;# $Id: altoids.pl,v 1.5 1999/01/25 18:35:12 dplonka Exp $
;# Dave Plonka <plonka@doit.wisc.edu>

%altoids = (

   iso => {
      humanoid => 'iso',
      oid => '1'
   },

   #############################################################################

   sysDescr => {
      rhs => 'string' # sysDescr is a printable ASCII string
   },

   #############################################################################

   ifAdminStatus => {
      humanoid => 'iso.org.dod.internet.mgmt.mib-2.interfaces.ifTable.ifEntry.ifAdminStatus',
      oid => '1.3.6.1.2.1.2.2.1.7',
      rhstrans => {
         1 => 'up(1)',
	 2 => 'down(2)',
	 3 => 'testing(3)'
      }
   },

   ifLastChange => {
      humanoid => 'iso.org.dod.internet.mgmt.mib-2.interfaces.ifTable.ifEntry.ifLastChange',
      oid => '1.3.6.1.2.1.2.2.1.9'
   },

   #############################################################################

   ciscoLecsMIBObjects => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLecsMIB.ciscoLecsMIBObjects',
      oid => '1.3.6.1.4.1.9.9.38.1'
   },

   lecsOperStatus => {
      rhstrans => {
         1 => 'active(1)',
	 2 => 'inactive(2)'
      }
   },

   lecsAdminStatus => {
      rhstrans => {
         1 => 'active(1)',
	 2 => 'inactive(2)'
      }
   },

   lecsStatus => {
      rhstrans => {
         1 => 'active(1)',
	 2 => 'notInService(2)',
	 3 => 'notReady(3)',
	 4 => 'createAndGo(4)',
	 5 => 'createAndWait(5)',
	 6 => 'destroy(6)'
      }
   },

   lecsAtmAddrEntry => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLecsMIB.ciscoLecsMIBObjects.lecs.lecsAtmAddrTable.lecsAtmAddrEntry',
      oid => '1.3.6.1.4.1.9.9.38.1.1.2.1'
   },

   lecsLesConfigTable => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLecsMIB.ciscoLecsMIBObjects.config.lecsLesConfigTable',
      oid => '1.3.6.1.4.1.9.9.38.1.2.5'
   },

   lecsLesConfigEntry => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLecsMIB.ciscoLecsMIBObjects.config.lecsLesConfigTable.lecsLesConfigEntry',
      oid => '1.3.6.1.4.1.9.9.38.1.2.5.1'
   },

   lecsLesConnState => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLecsMIB.ciscoLecsMIBObjects.config.lecsLesConfigTable.lecsLesConfigEntry.lecsLesConnState',
      oid => '1.3.6.1.4.1.9.9.38.1.2.5.1.3',
      lhs => ['nstring', 'nstring', 'atmaddr'],
      rhstrans => {
         1 => 'active(1)',
	 2 => 'inactive(2)',
	 3 => 'notConnected(3)'
      }
   },

   lecsLesPriority => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLecsMIB.ciscoLecsMIBObjects.config.lecsLesConfigTable.lecsLesConfigEntry.lecsLesPriority',
      oid => '1.3.6.1.4.1.9.9.38.1.2.5.1.2',
      lhs => ['nstring', 'nstring', 'atmaddr']
   },

   lecsLesConfigStatus => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLecsMIB.ciscoLecsMIBObjects.config.lecsLesConfigTable.lecsLesConfigEntry.lecsLesConfigStatus',
      oid => '1.3.6.1.4.1.9.9.38.1.2.5.1.4',
      lhs => ['nstring', 'nstring', 'atmaddr'],
      rhstrans => {
         1 => 'active(1)',
	 2 => 'notInService(2)',
	 3 => 'notReady(3)',
	 4 => 'createAndGo(4)',
	 5 => 'createAndWait(5)',
	 6 => 'destroy(6)'
      }
   },

   #############################################################################

   lesEntry => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLesMIB.ciscoLesMIBObjects.les.lesTable.lesEntry',
      oid => '1.3.6.1.4.1.9.9.39.1.1.1.1',
      lhs => ['nstring'],
   },

   lesAtmAddrSpec => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLesMIB.ciscoLesMIBObjects.les.lesTable.lesEntry.lesAtmAddrSpec',
      oid => '1.3.6.1.4.1.9.9.39.1.1.1.1.3',
      lhs => ['nstring'],
      rhs => 'atmaddr',
   },

   lesAtmAddrMask => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLesMIB.ciscoLesMIBObjects.les.lesTable.lesEntry.lesAtmAddrMask',
      oid => '1.3.6.1.4.1.9.9.39.1.1.1.1.4',
      lhs => ['nstring'],
      rhs => 'atmaddr',
   },

   lesAtmAddrActual => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLesMIB.ciscoLesMIBObjects.les.lesTable.lesEntry.lesAtmAddrActual',
      oid => '1.3.6.1.4.1.9.9.39.1.1.1.1.5',
      lhs => ['nstring'],
      rhs => 'atmaddr',
   },

   lesLecsAtmAddr => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLesMIB.ciscoLesMIBObjects.les.lesTable.lesEntry.lesLecsAtmAddr',
      oid => '1.3.6.1.4.1.9.9.39.1.1.1.1.15',
      lhs => ['nstring'],
      rhs => 'atmaddr',
   },

   lesIfIndex => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLesMIB.ciscoLesMIBObjects.les.lesTable.lesEntry.lesIfIndex',
      oid => '1.3.6.1.4.1.9.9.39.1.1.1.1.6',
      lhs => ['nstring'],
   },

   lesUpTime => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLesMIB.ciscoLesMIBObjects.les.lesTable.lesEntry.lesUpTime',
      oid => '1.3.6.1.4.1.9.9.39.1.1.1.1.11',
      lhs => ['nstring'],
   },

   lesStatus => {
      humanoid => 'iso.org.dod.internet.private.enterprises.cisco.ciscoMgmt.ciscoLesMIB.ciscoLesMIBObjects.les.lesTable.lesEntry.lesStatus',
      oid => '1.3.6.1.4.1.9.9.39.1.1.1.1.20',
      lhs => ['nstring'],
      rhstrans => {
         1 => 'active(1)',
	 2 => 'notInService(2)',
	 3 => 'notReady(3)',
	 4 => 'createAndGo(4)',
	 5 => 'createAndWait(5)',
	 6 => 'destroy(6)'
      },
   },

   lesClientEntry => {
      lhs => [ 'nstring' ]
   },

   lesMacRegEntry => {
      lhs => [ 'nstring', 'index', 'macaddr' ]
   },

   #############################################################################

   lecID => {
      humanoid => 'iso.org.dod.internet.private.enterprises.atmForum.atmForumNetworkManagement.atmfLanEmulation.leClientMIB.leClientMIBObjects.lecStatusTable.lecStatusEntry.lecID',
      oid => '1.3.6.1.4.1.353.5.3.1.1.2.1.3',
   },

   lecActualLesAtmAddress => {
      humanoid => 'iso.org.dod.internet.private.enterprises.atmForum.atmForumNetworkManagement.atmfLanEmulation.leClientMIB.leClientMIBObjects.lecStatusTable.lecStatusEntry.lecActualLesAtmAddress',
      oid => '1.3.6.1.4.1.353.5.3.1.1.2.1.15',
      rhs => 'atmaddr',
   },

   lecConfigServerAtmAddress => {
      humanoid => 'iso.org.dod.internet.private.enterprises.atmForum.atmForumNetworkManagement.atmfLanEmulation.leClientMIB.leClientMIBObjects.lecStatusTable.lecStatusEntry.lecConfigServerAtmAddress',
      oid => '1.3.6.1.4.1.353.5.3.1.1.2.1.10',
      rhs => 'atmaddr',
   },

   lecPrimaryAtmAddress => {
      humanoid => 'iso.org.dod.internet.private.enterprises.atmForum.atmForumNetworkManagement.atmfLanEmulation.leClientMIB.leClientMIBObjects.lecStatusTable.lecStatusEntry.lecPrimaryAtmAddress',
      oid => '1.3.6.1.4.1.353.5.3.1.1.2.1.2',
      rhs => 'atmaddr',
   },

   lecMacAddressEntry => {
      lhs => [ 'index', 'macaddr' ]
   },

   ipAddrEntry => {
      lhs => [ 'ipaddr' ]
   },

   lecsElanConfigEntry => {
      lhs => [ 'nstring', 'string' ]
   },

   ipxServEntry => {
      lhs => [ 'index', 'ushort', 'nstring' ]
   },

   ipxServType => {
      rhs => 'ushort'
   },
);
